/* -*- Mode: java; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 * Galatea Dialog Manager:
 *
 * (c)2003-2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
 *
 * $Id: GalateaGlobal.java,v 1.4 2008/02/15 03:26:00 nishi Exp $
 *
 * Wrappar class for Mozilla Rhino / shell Global class
 */

package galatea.scripting;

import org.mozilla.javascript.*;
import org.mozilla.javascript.tools.shell.*;

public class GalateaGlobal extends Global {
    public GalateaGlobal(Context cx) {
        super(cx);
    }
}


